package org.gnucash.android.test.db;

import java.util.List;

import org.gnucash.android.model.Account;
import org.gnucash.android.model.Transaction;
import org.gnucash.android.db.AccountsDbAdapter;
import org.gnucash.android.db.TransactionsDbAdapter;

import android.test.AndroidTestCase;

public class TransactionsDbAdapterTest extends AndroidTestCase {
	private static final String ALPHA_ACCOUNT_NAME = "Alpha";
	private static final String BRAVO_ACCOUNT_NAME = "Bravo";
	private static final String ALPHA_ACCOUNT_UID = "alpha-team";
	
	private TransactionsDbAdapter mAdapter;	
	
	@Override
	protected void setUp() throws Exception {
		super.setUp();
		mAdapter = new TransactionsDbAdapter(getContext());
		AccountsDbAdapter accountsAdapter = new AccountsDbAdapter(mContext);
		Account first = new Account(ALPHA_ACCOUNT_NAME);
		first.setUID(ALPHA_ACCOUNT_UID);
		Transaction t1 = new Transaction("T800");
		t1.setTime(System.currentTimeMillis() - 10000);
		Transaction t2 = new Transaction( "T1000");
		t2.setTime(System.currentTimeMillis());
		first.addTransaction(t1);
		first.addTransaction(t2);
		
		Account second = new Account(BRAVO_ACCOUNT_NAME);
		Transaction t = new Transaction( "buyout");
		second.addTransaction(t);
		
		accountsAdapter.addAccount(second);
		accountsAdapter.addAccount(first);
	}
	
	public void testTransactionsAreTimeSorted(){
		List<Transaction> transactionsList = mAdapter.getAllTransactionsForAccount(ALPHA_ACCOUNT_UID);
		assertEquals("T1000", transactionsList.get(0).getDescription());
		assertEquals("T800", transactionsList.get(1).getDescription());
	}
	
	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
		AccountsDbAdapter accAdapter = new AccountsDbAdapter(mContext);
		accAdapter.deleteAllRecords();
		accAdapter.close();
	}
}
